@@ -3,12 +3,13 @@
 import inspect
 import logging
 
-from .chain import Chain
-from .decorators import *
-from .ref import OpRef
-from .reflect import Meta
-from .state import Op, State, Tuple
-from .util import form_of, ref as get_ref, uri, URI, to_json
+from tinychain import ref
+from tinychain.decorators import *
+from tinychain.op import Op
+from tinychain.reflect.meta import Meta
+from tinychain.state import State, Tuple
+from tinychain.util import form_of, uri, URI, to_json
+
 
 class Cluster(object, metaclass=Meta):
     """A hosted Tinychain service."""
@@ -37,6 +38,9 @@ class Cluster(object, metaclass=Meta):
         return instance
 
     def __init__(self, form=None):
+        if isinstance(form, URI):
+            self.__uri__ = form
+
         self.__form__ = form if form else uri(self).path()
         self._configure()
 
@@ -55,7 +59,7 @@ class Cluster(object, metaclass=Meta):
     def authorize(self, scope):
         """Raise an error if the current transaction has not been granted the given scope."""
 
-        return OpRef.Get(uri(self) + "/authorize", scope)
+        return ref.Get(uri(self) + "/authorize", scope)
 
     def grant(self, scope, op: Op, **context):
         """Execute the given `op` after granting it the given `scope`."""
@@ -68,7 +72,7 @@ class Cluster(object, metaclass=Meta):
         if context:
             params["context"] = context
 
-        return OpRef.Post(uri(self) + "/grant", **params)
+        return ref.Post(uri(self) + "/grant", **params)
 
     @put_method
     def install(self, txn, cluster_link: URI, scopes: Tuple):
