@@ -1,8 +1,7 @@
-"""Tinychain `State`\s, such as `Map`, `Tuple`, and `Op`."""
+"""Tinychain `State` s, such as `Map`, `Tuple`, and `Op`."""
 
-from . import reflect
-from .ref import MethodSubject, Ref, OpRef
-from .util import *
+from tinychain import ref, reflect
+from tinychain.util import *
 
 
 class State(object):
@@ -20,11 +19,11 @@ class State(object):
         if isinstance(form, URI):
             self.__uri__ = form
 
-        reflect.gen_headers(self)
+        reflect.meta.gen_headers(self)
 
     def __json__(self):
         form = form_of(self)
-        if isinstance(form, URI) or isinstance(form, OpRef):
+        if isinstance(form, URI) or isinstance(form, ref.Op):
             return to_json(form)
         else:
             return {str(uri(self)): [to_json(form)]}
@@ -32,7 +31,7 @@ class State(object):
     def __ns__(self, cxt):
         form = form_of(self)
 
-        if isinstance(form, OpRef):
+        if isinstance(form, ref.Op):
             deanonymize(form, cxt)
 
     def __ref__(self, name):
@@ -42,8 +41,8 @@ class State(object):
         return f"{self.__class__.__name__}({form_of(self)})"
 
     def _method(self, name):
-        if isinstance(form_of(self), OpRef):
-            return MethodSubject(self, name)
+        if isinstance(form_of(self), ref.Op):
+            return ref.MethodSubject(self, name)
 
         subject = uri(self).append(name)
         if subject.startswith("/state") and subject.path() != uri(self.__class__):
@@ -55,34 +54,32 @@ class State(object):
     def _get(self, name, key=None, rtype=None):
         subject = self._method(name)
         rtype = State if rtype is None else rtype
-        return rtype(OpRef.Get(subject, key))
+        return rtype(ref.Get(subject, key))
 
     def _put(self, name, key=None, value=None):
         from .value import Nil
 
         subject = self._method(name)
-        return Nil(OpRef.Put(subject, key, value))
+        return Nil(ref.Put(subject, key, value))
 
     def _post(self, _method_name, rtype=None, **params):
-        from .value import Nil
-
         subject = self._method(_method_name)
         rtype = State if rtype is None else rtype
-        return rtype(OpRef.Post(subject, **params))
+        return rtype(ref.Post(subject, **params))
 
     def _delete(self, name, key=None):
         from .value import Nil
 
         subject = self._method(name)
-        return Nil(OpRef.Delete(subject, key))
+        return Nil(ref.Delete(subject, key))
 
     def dtype(self):
         """Return the native :class:`Class` of this `State`."""
-        return Class(OpRef.Get(uri(self) + "/class"))
+        return Class(ref.Get(uri(self) + "/class"))
 
 
 class Map(State):
-    """A key-value map whose keys are `Id`\s and whose values are `State`\s."""
+    """A key-value map whose keys are `Id`s and whose values are `State` s."""
 
     __uri__ = uri(State) + "/map"
 
@@ -94,7 +91,7 @@ class Map(State):
 
 
 class Tuple(State):
-    """A tuple of `State`\s."""
+    """A tuple of `State` s."""
 
     __uri__ = uri(State) + "/tuple"
 
@@ -120,56 +117,6 @@ class Scalar(State):
         return to_json(form_of(self))
 
 
-# User-defined Ops
-
-class Op(Scalar):
-    """A callable function."""
-
-    __uri__ = uri(Scalar) + "/op"
-
-
-class GetOp(Op):
-    """A function which can be called via a GET request."""
-
-    __uri__ = uri(Op) + "/get"
-
-    def __call__(self, key=None):
-        return OpRef.Get(self, key)
-
-
-class PutOp(Op):
-    """A function which can be called via a PUT request."""
-
-    __uri__ = uri(Op) + "/put"
-
-    def __call__(self, key=None, value=None):
-        return OpRef.Put(self, key, value)
-
-
-class PostOp(Op):
-    """A function which can be called via a POST request."""
-
-    __uri__ = uri(Op) + "/post"
-
-    def __call__(self, **params):
-        return OpRef.Post(self, **params)
-
-
-class DeleteOp(Op):
-    """A function which can be called via a DELETE request."""
-
-    __uri__ = uri(Op) + "/delete"
-
-    def __call__(self, key=None):
-        return OpRef.Delete(self, key)
-
-
-Op.Get = GetOp
-Op.Put = PutOp
-Op.Post = PostOp
-Op.Delete = DeleteOp
-
-
 # User-defined object types
 
 class Class(State):
