@@ -39,7 +39,7 @@ class Context(object):
                 from .state import Class
                 return Class(URI(name))
             elif hasattr(value, "__ref__"):
-                return ref(value, name)
+                return get_ref(value, name)
             else:
                 return URI(name)
         else:
@@ -77,7 +77,7 @@ def form_of(state):
         raise ValueError(f"{state} has no form")
 
 
-def ref(subject, name):
+def get_ref(subject, name):
     """Return a named reference to the given state."""
 
     if hasattr(subject, "__ref__"):
@@ -99,7 +99,7 @@ class URI(object):
     def __init__(self, root, path=[]):
         assert root is not None
 
-        self._root = root
+        self._root = str(root)
         self._path = path
 
     def append(self, name):
@@ -134,16 +134,17 @@ class URI(object):
     def path(self):
         """Return the path segment of this `URI`."""
 
-        if "://" not in self._root:
-            return self._root + "/".join(self._path)
+        if "://" not in str(self._root):
+            return URI(self._root) + "/".join(self._path)
 
         start = self._root.index("://")
         start = self._root.index('/', start + 3)
 
+        prefix = URI(self._root[start:])
         if self._path:
-            return self._root[start:] + "/".join(self._path)
+            return prefix + "/".join(self._path)
         else:
-            return self._root[start:]
+            return prefix
 
     def port(self):
         """Return the port of this `URI`, if present."""
@@ -237,6 +238,8 @@ def to_json(obj):
 
 
 def deanonymize(state, context):
+    """Assign an auto-generated name to the given state within the given context."""
+
     if hasattr(state, "__ns__"):
         state.__ns__(context)
     elif isinstance(state, tuple) or isinstance(state, list):
@@ -245,4 +248,3 @@ def deanonymize(state, context):
     elif isinstance(state, dict):
         for key in state:
             deanonymize(state[key], context)
-
