@@ -1,9 +1,8 @@
 """:class:`Value` types such as :class:`Nil`, :class:`Number`, and :class:`String`."""
 
-from .ref import OpRef
-from .reflect import Meta
-from .state import Scalar
-from .util import uri
+from tinychain.reflect import Meta
+from tinychain.state import Scalar
+from tinychain.util import uri
 
 
 # Scalar value types
@@ -49,12 +48,18 @@ class Number(Value):
 
     __uri__ = uri(Value) + "/number"
 
+    def __abs__(self):
+        return self.abs()
+
     def __add__(self, other):
         return self.add(other)
 
     def __div__(self, other):
         return self.div(other)
 
+    def __eq__(self, other):
+        return self.eq(other)
+
     def __gt__(self, other):
         return self.gt(other)
 
@@ -70,6 +75,9 @@ class Number(Value):
     def __mul__(self, other):
         return self.mul(other)
 
+    def __ne__(self, other):
+        return self.ne(other)
+
     def __radd__(self, other):
         return self.add(other)
 
@@ -82,6 +90,11 @@ class Number(Value):
     def __truediv__(self, other):
         return self.div(other)
 
+    def abs(self):
+        """Return this number's absolute value"""
+
+        return self._get("abs", rtype=self.__class__)
+
     def add(self, other):
         """Return the sum of `self` and `other`."""
 
@@ -92,6 +105,11 @@ class Number(Value):
 
         return self._get("div", other, self.__class__)
 
+    def eq(self, other):
+        """Return true if `self` is equal to `other`."""
+
+        return self._get("eq", other, Bool)
+
     def gt(self, other):
         """Return true if `self` is greater than `other`."""
 
@@ -117,6 +135,11 @@ class Number(Value):
 
         return self._get("mul", other, self.__class__)
 
+    def ne(self, other):
+        """Return true if `self` is not equal to `other`."""
+
+        return self._get("ne", other, Bool)
+
     def sub(self, other):
         """Return the difference between `self` and `other`."""
 
@@ -134,6 +157,16 @@ class Complex(Number):
 
     __uri__ = uri(Number) + "/complex"
 
+    def abs(self):
+        """Return the linear norm of this complex number."""
+
+        return Number.abs(self)
+
+    def norm(self):
+        """Return the linear norm of this complex number."""
+
+        return self.abs()
+
 
 class C32(Complex):
     """A complex 32-bit floating point number."""
